/***************************************************************************
 *                                                                         *
 *   KNetLoad is copyright (c) 1999-2000, Markus Gustavsson                *
 *                         (c) 2002, Ben Burton                            *
 *                         (c) 2004, Diego Pettenò                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef NETLOADAPPLET_H
#define NETLOADAPPLET_H

#include <kpanelapplet.h>

class StatLabel;
class QResizeEvent;
class KAboutApplication;
class KConfigDialog;
class StatPopup;
class StatGraph;
class KNetProc;

/**
 * @author Diego 'Flameeyes' Pettenò
 * @brief Applet for KNetLoad
 *
 * This class is an implementation of KNetLoad which instead of using
 * system tray icons, creates an applet to show the graphs.
 * This makes it bigger than the simple icons, because it uses all the height
 * of the panel.
 */
class NetLoadApplet : public KPanelApplet
{
Q_OBJECT
public:
	NetLoadApplet(const QString& configFile, Type t = Normal, int actions = 0,
		QWidget *parent = 0, const char *name = 0);
	~NetLoadApplet();

	/**
	 * @brief Gets the width of the applet when set the height.
	 * @param height Height the apple is resized to.
	 */
	virtual int widthForHeight(int height) const;

	/**
	 * @brief Gets the height of the applet when set the width.
	 * @param width Width the apple is resized to.
	 */
	virtual int heightForWidth(int width) const;

	/// @brief Shows the about dialog for the applet.
	virtual void about();
	
	/// @brief Shows the preferences dialog for the applet.
	virtual void preferences();
protected slots:
	virtual void reloadSettings();
	virtual void takeReading();
	virtual void togglePopup();
	
protected:
	virtual void resizeEvent(QResizeEvent *e);
private:
	StatPopup *m_popup;
		///< Popup dialog which shows the current load
	QTimer *m_readTimer;
		///< Timer to read the values of loads
	StatLabel *m_labelIn;
		///< Input graph's label
	StatLabel *m_labelOut;
		///< Output graph's label
	KNetProc* m_proc;
		///< Interface to optain the raw network data from.
	
	KAboutApplication *m_aboutbox;
		///< About data for the applet.
	KConfigDialog *m_cfgdialog;
		///< Configuration dialog for the applet.
};

#endif
